module.exports = [
	{
		"_id": "5e16d8c6d7eee2857c907fbe",
		"index": 0,
		"nickname": null,
		"isActive": false,
		"balance": 2077.55,
		"password": undefined,
		"picture": "http://placehold.it/32x32",
		"age": 33,
		"joined": new Date(),
		"locales": /(EN|ES)/i,
		"details": {
			"email": "ericksonphillips@retrotex.com",
			"address": {
				"street": "554 Lyme Avenue",
				"city": "Harborton",
				"state": "Texas",
				"zipcode": 4945,
				"coords": {
					"latitude": 61.497735,
					"longitude": -38.711066
				}
			}
		},
		"interests": [
			"amet",
			"voluptate",
			"sit",
			"duis",
			"fugiat",
			"consectetur",
			"amet"
		],
		"friends": [
			{
				"id": 0,
				"name": "Belinda Chandler",
				"friends_common": {
					"count": 2,
					"friends_of_friends": [
						{
							"id": 0,
							"name": "George Ayala"
						},
						{
							"id": 1,
							"name": "Nadia Nguyen"
						}
					]
				}
			},
			{
				"id": 1,
				"name": "Sheena Kidd",
				"friends_common": {
					"count": 2,
					"friends_of_friends": [
						{
							"id": 0,
							"name": "Kimberly Martinez"
						},
						{
							"id": 1,
							"name": "Meadows Fitzpatrick"
						}
					]
				}
			},
			{
				"id": 2,
				"name": "Winnie Mccarthy",
				"friends_common": {
					"count": 2,
					"friends_of_friends": [
						{
							"id": 0,
							"name": "Robbie Dale"
						},
						{
							"id": 1,
							"name": "Orr Houston"
						}
					]
				}
			}
		]
	},
	{
		"_id": "5e16d8c6ed426d1c22bf306b",
		"index": 1,
		"nickname": null,
		"isActive": false,
		"balance": 2916.08,
		"password": undefined,
		"picture": "http://placehold.it/32x32",
		"age": 20,
		"joined": new Date(),
		"locales": /(EN)/i,
		"details": {
			"email": "orrhouston@retrotex.com",
			"address": {
				"street": "962 McDonald Avenue",
				"city": "Lithium",
				"state": "West Virginia",
				"zipcode": 4536,
				"coords": {
					"latitude": 83.372808,
					"longitude": 150.181923
				}
			}
		},
		"interests": [
			"eu",
			"et",
			"dolore",
			"sunt",
			"elit",
			"nulla",
			"fugiat"
		],
		"friends": [
			{
				"id": 0,
				"name": "Hood Washington",
				"friends_common": {
					"count": 2,
					"friends_of_friends": [
						{
							"id": 0,
							"name": "Hebert Delacruz"
						},
						{
							"id": 1,
							"name": "Sharp Rose"
						}
					]
				}
			},
			{
				"id": 1,
				"name": "Karla Velasquez",
				"friends_common": {
					"count": 2,
					"friends_of_friends": [
						{
							"id": 0,
							"name": "Carey Holman"
						},
						{
							"id": 1,
							"name": "Baird Short"
						}
					]
				}
			},
			{
				"id": 2,
				"name": "Juliet Oneal",
				"friends_common": {
					"count": 2,
					"friends_of_friends": [
						{
							"id": 0,
							"name": "Owens Richards"
						},
						{
							"id": 1,
							"name": "Lily Olsen"
						}
					]
				}
			}
		]
	}
]
